@@ -10,7 +10,7 @@ sub new {
 	bless $self, $class;
 }
 
-sub dispatch_single_line {
+sub filter {
 	my ($self, $imgrepr, @rgba_points) = @_;
 
 	my @non_return_rgba_points = @rgba_points;
